package SPVM::Sys::IO::Dirent;

1;

=head1 Name

SPVM::Sys::IO::Dirent - struct dirent in C language

=head1 Usage
  
  use Sys::IO::Dirent;

=head1 Description

C<Sys::IO::Dirent> is the class for C<struct dirent> in C<C language>.

This is a L<pointer class|SPVM::Document::Language/"Pointer Class">.
