package SPVM::Sys::Process::Tms;

1;

=head1 Name

SPVM::Sys::Process::Tms - Sys::Process::Tms is a SPVM module

=head1 Usage

  use Sys::Process::Tms;
  
=head1 Description

C<Sys::Process::Tms> is a L<SPVM> module.

=head1 Fields



=head1 Class Methods



=head1 Instance Methods



=head1 Repository



=head1 Author

[--user-name] C<[--user-email]>

=head1 Copyright & License

Copyright 2022-2022 [--user-name], all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

